diff --git a/drivers/net/bnxt/bnxt_rxtx_vec_avx2.c b/drivers/net/bnxt/bnxt_rxtx_vec_avx2.c
index ea8dbaf..5f92e0f 100644
--- a/drivers/net/bnxt/bnxt_rxtx_vec_avx2.c
+++ b/drivers/net/bnxt/bnxt_rxtx_vec_avx2.c
@@ -266,7 +266,7 @@
 		if (num_valid == 0)
 			break;
 
 		/* Update mbuf rearm_data for eight packets. */
 		mbuf01 = _mm256_shuffle_epi8(rxcmp0_1, shuf_msk);
 		mbuf23 = _mm256_shuffle_epi8(rxcmp2_3, shuf_msk);
 		mbuf45 = _mm256_shuffle_epi8(rxcmp4_5, shuf_msk);
@@ -310,13 +310,13 @@
 					    0x04);
 
 		/* Store all mbuf fields for first four packets. */
-		_mm256_storeu_si256((void *)&rx_pkts[i + 0]->rearm_data,
+		_mm256_storeu_si256((void *)&rx_pkts[i + 0]->mbuf_rearm_data,
 				    rearm0);
-		_mm256_storeu_si256((void *)&rx_pkts[i + 1]->rearm_data,
+		_mm256_storeu_si256((void *)&rx_pkts[i + 1]->mbuf_rearm_data,
 				    rearm1);
-		_mm256_storeu_si256((void *)&rx_pkts[i + 2]->rearm_data,
+		_mm256_storeu_si256((void *)&rx_pkts[i + 2]->mbuf_rearm_data,
 				    rearm2);
-		_mm256_storeu_si256((void *)&rx_pkts[i + 3]->rearm_data,
+		_mm256_storeu_si256((void *)&rx_pkts[i + 3]->mbuf_rearm_data,
 				    rearm3);
 
 		/* Unpack rearm data, set fixed fields for final four mbufs. */
@@ -336,13 +336,13 @@
 					    0x04);
 
 		/* Store all mbuf fields for final four packets. */
-		_mm256_storeu_si256((void *)&rx_pkts[i + 4]->rearm_data,
+		_mm256_storeu_si256((void *)&rx_pkts[i + 4]->mbuf_rearm_data,
 				    rearm4);
-		_mm256_storeu_si256((void *)&rx_pkts[i + 5]->rearm_data,
+		_mm256_storeu_si256((void *)&rx_pkts[i + 5]->mbuf_rearm_data,
 				    rearm5);
-		_mm256_storeu_si256((void *)&rx_pkts[i + 6]->rearm_data,
+		_mm256_storeu_si256((void *)&rx_pkts[i + 6]->mbuf_rearm_data,
 				    rearm6);
-		_mm256_storeu_si256((void *)&rx_pkts[i + 7]->rearm_data,
+		_mm256_storeu_si256((void *)&rx_pkts[i + 7]->mbuf_rearm_data,
 				    rearm7);
 
 		nb_rx_pkts += num_valid;
@@ -266,7 +266,7 @@
 			break;
 
-		/* Update mbuf rearm_data for eight packets. */
+		/* Update mbuf mbuf_rearm_data for eight packets. */
 		mbuf01 = _mm256_shuffle_epi8(rxcmp0_1, shuf_msk);
 		mbuf23 = _mm256_shuffle_epi8(rxcmp2_3, shuf_msk);
diff --git a/drivers/net/bnxt/bnxt_rxtx_vec_common.h b/drivers/net/bnxt/bnxt_rxtx_vec_common.h
index 2294f0a..05a52d2 100644
--- a/drivers/net/bnxt/bnxt_rxtx_vec_common.h
+++ b/drivers/net/bnxt/bnxt_rxtx_vec_common.h
@@ -44,9 +44,9 @@
 	mb_def.port = rxq->port_id;
 	rte_mbuf_refcnt_set(&mb_def, 1);
 
 	/* prevent compiler reordering: rearm_data covers previous fields */
 	rte_compiler_barrier();
-	p = (uintptr_t)&mb_def.rearm_data;
+	p = (uintptr_t)&mb_def.mbuf_rearm_data;
 	rxq->mbuf_initializer = *(uint64_t *)p;
 	rxq->rxrearm_nb = 0;
 	rxq->rxrearm_start = 0;
@@ -44,9 +44,9 @@
 	rte_mbuf_refcnt_set(&mb_def, 1);
 
-	/* prevent compiler reordering: rearm_data covers previous fields */
+	/* prevent compiler reordering: mbuf_rearm_data covers previous fields */
 	rte_compiler_barrier();
diff --git a/drivers/net/bnxt/bnxt_rxtx_vec_neon.c b/drivers/net/bnxt/bnxt_rxtx_vec_neon.c
index 775400f..7156f05 100644
--- a/drivers/net/bnxt/bnxt_rxtx_vec_neon.c
+++ b/drivers/net/bnxt/bnxt_rxtx_vec_neon.c
@@ -133,29 +133,29 @@
 	errors = vorrq_u32(errors, vshrq_n_u32(is_tunnel, 1));
 	index = vorrq_u32(index, is_tunnel);
 
 	/* Update mbuf rearm_data for four packets. */
 	GET_OL_FLAGS(rss_flags, index, errors, 0, ol_flags);
-	vst1q_u32((uint32_t *)&mbuf[0]->rearm_data,
+	vst1q_u32((uint32_t *)&mbuf[0]->mbuf_rearm_data,
 		  vsetq_lane_u32(ol_flags, vreinterpretq_u32_u64(mb_init), 2));
 	GET_OL_FLAGS(rss_flags, index, errors, 1, ol_flags);
-	vst1q_u32((uint32_t *)&mbuf[1]->rearm_data,
+	vst1q_u32((uint32_t *)&mbuf[1]->mbuf_rearm_data,
 		  vsetq_lane_u32(ol_flags, vreinterpretq_u32_u64(mb_init), 2));
 	GET_OL_FLAGS(rss_flags, index, errors, 2, ol_flags);
-	vst1q_u32((uint32_t *)&mbuf[2]->rearm_data,
+	vst1q_u32((uint32_t *)&mbuf[2]->mbuf_rearm_data,
 		  vsetq_lane_u32(ol_flags, vreinterpretq_u32_u64(mb_init), 2));
 	GET_OL_FLAGS(rss_flags, index, errors, 3, ol_flags);
-	vst1q_u32((uint32_t *)&mbuf[3]->rearm_data,
+	vst1q_u32((uint32_t *)&mbuf[3]->mbuf_rearm_data,
 		  vsetq_lane_u32(ol_flags, vreinterpretq_u32_u64(mb_init), 2));
 
 	/* Update mbuf rx_descriptor_fields1 for four packets. */
 	GET_DESC_FIELDS(mm_rxcmp[0], mm_rxcmp1[0], shuf_msk, ptype_idx, 0, tmp);
-	vst1q_u32((uint32_t *)&mbuf[0]->rx_descriptor_fields1, tmp);
+	vst1q_u32((uint32_t *)&mbuf[0]->mbuf_rx_descriptor_fields1, tmp);
 	GET_DESC_FIELDS(mm_rxcmp[1], mm_rxcmp1[1], shuf_msk, ptype_idx, 1, tmp);
-	vst1q_u32((uint32_t *)&mbuf[1]->rx_descriptor_fields1, tmp);
+	vst1q_u32((uint32_t *)&mbuf[1]->mbuf_rx_descriptor_fields1, tmp);
 	GET_DESC_FIELDS(mm_rxcmp[2], mm_rxcmp1[2], shuf_msk, ptype_idx, 2, tmp);
-	vst1q_u32((uint32_t *)&mbuf[2]->rx_descriptor_fields1, tmp);
+	vst1q_u32((uint32_t *)&mbuf[2]->mbuf_rx_descriptor_fields1, tmp);
 	GET_DESC_FIELDS(mm_rxcmp[3], mm_rxcmp1[3], shuf_msk, ptype_idx, 3, tmp);
-	vst1q_u32((uint32_t *)&mbuf[3]->rx_descriptor_fields1, tmp);
+	vst1q_u32((uint32_t *)&mbuf[3]->mbuf_rx_descriptor_fields1, tmp);
 }
 
 static uint16_t
@@ -133,29 +133,29 @@
 	index = vorrq_u32(index, is_tunnel);
 
-	/* Update mbuf rearm_data for four packets. */
+	/* Update mbuf mbuf_rearm_data for four packets. */
 	GET_OL_FLAGS(rss_flags, index, errors, 0, ol_flags);
@@ -133,29 +133,29 @@
 		  vsetq_lane_u32(ol_flags, vreinterpretq_u32_u64(mb_init), 2));
 
-	/* Update mbuf rx_descriptor_fields1 for four packets. */
+	/* Update mbuf mbuf_rx_descriptor_fields1 for four packets. */
 	GET_DESC_FIELDS(mm_rxcmp[0], mm_rxcmp1[0], shuf_msk, ptype_idx, 0, tmp);
diff --git a/drivers/net/bnxt/bnxt_rxtx_vec_sse.c b/drivers/net/bnxt/bnxt_rxtx_vec_sse.c
index 8ef51ce..b4e6fa6 100644
--- a/drivers/net/bnxt/bnxt_rxtx_vec_sse.c
+++ b/drivers/net/bnxt/bnxt_rxtx_vec_sse.c
@@ -118,35 +118,35 @@
 	errors = _mm_or_si128(errors, _mm_srli_epi32(is_tunnel, 1));
 	index = _mm_or_si128(index, is_tunnel);
 
 	/* Update mbuf rearm_data for four packets. */
 	GET_OL_FLAGS(rss_flags, index, errors, 0, ol_flags);
-	_mm_store_si128((void *)&mbuf[0]->rearm_data,
+	_mm_store_si128((void *)&mbuf[0]->mbuf_rearm_data,
 			_mm_or_si128(mbuf_init, _mm_set_epi64x(ol_flags, 0)));
 
 	GET_OL_FLAGS(rss_flags, index, errors, 1, ol_flags);
-	_mm_store_si128((void *)&mbuf[1]->rearm_data,
+	_mm_store_si128((void *)&mbuf[1]->mbuf_rearm_data,
 			_mm_or_si128(mbuf_init, _mm_set_epi64x(ol_flags, 0)));
 
 	GET_OL_FLAGS(rss_flags, index, errors, 2, ol_flags);
-	_mm_store_si128((void *)&mbuf[2]->rearm_data,
+	_mm_store_si128((void *)&mbuf[2]->mbuf_rearm_data,
 			_mm_or_si128(mbuf_init, _mm_set_epi64x(ol_flags, 0)));
 
 	GET_OL_FLAGS(rss_flags, index, errors, 3, ol_flags);
-	_mm_store_si128((void *)&mbuf[3]->rearm_data,
+	_mm_store_si128((void *)&mbuf[3]->mbuf_rearm_data,
 			_mm_or_si128(mbuf_init, _mm_set_epi64x(ol_flags, 0)));
 
 	/* Update mbuf rx_descriptor_fields1 for four packes. */
 	GET_DESC_FIELDS(mm_rxcmp[0], mm_rxcmp1[0], shuf_msk, ptype_idx, 0, t0);
-	_mm_store_si128((void *)&mbuf[0]->rx_descriptor_fields1, t0);
+	_mm_store_si128((void *)&mbuf[0]->mbuf_rx_descriptor_fields1, t0);
 
 	GET_DESC_FIELDS(mm_rxcmp[1], mm_rxcmp1[1], shuf_msk, ptype_idx, 1, t0);
-	_mm_store_si128((void *)&mbuf[1]->rx_descriptor_fields1, t0);
+	_mm_store_si128((void *)&mbuf[1]->mbuf_rx_descriptor_fields1, t0);
 
 	GET_DESC_FIELDS(mm_rxcmp[2], mm_rxcmp1[2], shuf_msk, ptype_idx, 2, t0);
-	_mm_store_si128((void *)&mbuf[2]->rx_descriptor_fields1, t0);
+	_mm_store_si128((void *)&mbuf[2]->mbuf_rx_descriptor_fields1, t0);
 
 	GET_DESC_FIELDS(mm_rxcmp[3], mm_rxcmp1[3], shuf_msk, ptype_idx, 3, t0);
-	_mm_store_si128((void *)&mbuf[3]->rx_descriptor_fields1, t0);
+	_mm_store_si128((void *)&mbuf[3]->mbuf_rx_descriptor_fields1, t0);
 }
 
 static uint16_t
@@ -118,35 +118,35 @@
 	index = _mm_or_si128(index, is_tunnel);
 
-	/* Update mbuf rearm_data for four packets. */
+	/* Update mbuf mbuf_rearm_data for four packets. */
 	GET_OL_FLAGS(rss_flags, index, errors, 0, ol_flags);
@@ -118,35 +118,35 @@
 			_mm_or_si128(mbuf_init, _mm_set_epi64x(ol_flags, 0)));
 
-	/* Update mbuf rx_descriptor_fields1 for four packes. */
+	/* Update mbuf mbuf_rx_descriptor_fields1 for four packes. */
 	GET_DESC_FIELDS(mm_rxcmp[0], mm_rxcmp1[0], shuf_msk, ptype_idx, 0, t0);
